@@ -415,14 +415,15 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 
           // qDebug() << "Going to combine a new qualified mass spectrum.";
 
-          //std::size_t before_size = current_map_trace_sp->size();
+          // std::size_t before_size = current_map_trace_sp->size();
 
           trace_plus_combiner.combine(*current_map_trace_sp, filtered_trace);
 
-          //std::size_t after_size = current_map_trace_sp->size();
+          // std::size_t after_size = current_map_trace_sp->size();
 
-          //qDebug() << "Before combination, map trace map size: " << before_size
-                   //<< "after combination:" << after_size;
+          // qDebug() << "Before combination, map trace map size: " <<
+          // before_size
+          //<< "after combination:" << after_size;
 
           // qDebug() << "Processed one more spectrum.";
 
@@ -559,6 +560,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // Now we can create the bins!
   std::vector<double> bins = local_mz_integration_params.createBins();
 
+#if 0
   QString bins_before = "Bins:\n";
   for(auto &&bin : bins)
     bins_before += QString("%1\n").arg(bin, 0, 'f', 6);
@@ -566,6 +568,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
     // qDebug() << "Created bins at:"
     //<< QDateTime::currentDateTime().toString("yyyyMMdd-HH-mm-ss");
 
+#endif
+
 
 #if 0
   QString fileName = "/tmp/massSpecArbitraryBins.txt-at-" +
@@ -626,6 +630,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
   template_plus_combiner.setBins(bins);
 
+
+#if 0
   QString bins_after = "Bins:\n";
   for(auto &&bin : template_plus_combiner.getBins())
     bins_after += QString("%1\n").arg(bin, 0, 'f', 6);
@@ -635,6 +641,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   else
     qFatal("Programming error.");
 
+#endif
+
   // At this point, allocate a visitor that is specific for the calculation
   // of the mass spectrum. Since we are not binning, we can use a visitor
   // that integrates to a pappso::Trace, not a pappso::MassSpectrum.
@@ -742,13 +750,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
           if(!checkMsLevel(qualified_mass_spectrum_csp))
             {
-              //qDebug() << "The MsLevel check returned false";
+              // qDebug() << "The MsLevel check returned false";
               ++current_iterator;
               continue;
             }
           if(!checkMsFragmentation(qualified_mass_spectrum_csp))
             {
-              //qDebug() << "The MsFragmentation check returned false";
+              // qDebug() << "The MsFragmentation check returned false";
               ++current_iterator;
               continue;
             }
@@ -757,13 +765,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
           if(!checkRtRange(qualified_mass_spectrum_csp))
             {
-              //qDebug() << "checkRtRange failed check.";
+              // qDebug() << "checkRtRange failed check.";
               ++current_iterator;
               continue;
             }
           if(!checkDtRange(qualified_mass_spectrum_csp))
             {
-              //qDebug() << "checkDtRange failed check.";
+              // qDebug() << "checkDtRange failed check.";
               ++current_iterator;
               continue;
             }
@@ -859,18 +867,23 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // operation be cancelled once more. But we want that at least the
   // performed work be used to show the trace.
 
+  m_isOperationCancelled = false;
+
+  // Now we need to combine all the map traces processed concurrently into a
+  // single map trace. For that we instanciate another mass spectrum combiner,
+  // set the bins to it and then compute the combinations using it.
+
   pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner(
     local_mz_integration_params.getDecimalPlaces());
 
   mass_spectrum_plus_combiner.setBins(bins);
 
-  m_isOperationCancelled = false;
-  int iter               = 0;
-
   // qDebug() << "The vector of map traces has:" <<
   // vector_of_map_trace.size()
   //<< "items.";
 
+  int iter = 0;
+
   for(auto &&current_map_trace_sp : vector_of_map_trace)
     {
       if(m_isOperationCancelled)
